=========
Community
=========

Join the Salt!

There are many ways to participate in and communicate with the Salt community.

Salt has an active IRC channel and a mailing list.

.. _community-mailing-list:

Mailing List
============

Join the `salt-users mailing list`_. It is the best place to ask questions
about Salt and see whats going on with Salt development! The Salt mailing list
is hosted by Google Groups. It is open to new members.

https://groups.google.com/forum/#!forum/salt-users

.. _`salt-users mailing list`: https://groups.google.com/forum/#!forum/salt-users

.. _community-irc:

IRC
===

The ``#salt`` IRC channel is hosted on the popular `Freenode`__ network. You
can use the `Freenode webchat client`__ right from your browser.

`Logs of the IRC channel activity`__ are being collected courtesy of Moritz Lenz.

.. __: http://freenode.net/irc_servers.shtml
.. __: http://webchat.freenode.net/?channels=salt&uio=Mj10cnVlJjk9dHJ1ZSYxMD10cnVl83
.. __: http://irclog.perlgeek.de/salt/

.. _community-github:

Follow on Github
================

The Salt code is developed via Github. Follow Salt for constant updates on what
is happening in Salt development:

|saltrepo|

.. _community-blog:

The Red45 Blog
==============

News and thoughts on Salt and related projects is often posted on Thomas' blog
`The Red45`_:

http://red45.wordpress.com/

.. _`The Red45`: http://red45.wordpress.com/


Example Salt States
===================
The official ``salt-states`` repository is:
https://github.com/saltstack/salt-states

A few examples of salt states from the community:

* https://github.com/blast-hardcheese/blast-salt-states
* https://github.com/kevingranade/kevingranade-salt-state
* https://github.com/uggedal/states
* https://github.com/mattmcclean/salt-openstack/tree/master/salt

Follow on ohloh
===============

https://www.ohloh.net/p/salt

Developing Salt
===============

If you want to help develop Salt there is a great need and your patches are
welcome!

To assist in Salt development, you can help in a number of ways.

Posting patches to the mailing list
-----------------------------------

If you have a patch for Salt, please format it via :command:`git format-patch` and
send it to the Salt users mailing list. This allows the patch to give you the
contributor the credit for your patch, and gives the Salt community an archive
of the patch and a place for discussion.

Setting a Github pull request
-----------------------------

This is probably the preferred method for contributions, simply create a Github
fork, commit your changes to the fork, and then open up a pull request.

Contributions Welcome!
----------------------

The goal here it to make contributions clear, make sure there is a trail for
where the code has come from, but most importantly, to give credit where credit
is due!

The `Open Comparison Contributing Docs`__ has some good suggestions and tips for
those who are looking forward to contribute.

.. __: http://opencomparison.readthedocs.org/en/latest/contributing.html
